from typing import final, overload

from mypy_extensions import i64

def random() -> float: ...
def randint(a: i64, b: i64) -> i64: ...
@overload
def randrange(stop: i64, /) -> i64: ...
@overload
def randrange(start: i64, stop: i64, /) -> i64: ...
def seed(n: i64, /) -> None: ...

@final
class Random:
    def __init__(self, seed: i64 | None = None) -> None: ...
    def randint(self, a: i64, b: i64) -> i64: ...
    @overload
    def randrange(self, stop: i64, /) -> i64: ...
    @overload
    def randrange(self, start: i64, stop: i64, /) -> i64: ...
    def random(self) -> float: ...
    def seed(self, n: i64, /) -> None: ...
